/*
 * Copyright Object Matrix 2018
 */

package com.om.mxs.client.japi.samples;

import java.io.IOException;

import com.om.mxs.client.japi.MatrixStore;
import com.om.mxs.client.japi.MatrixStoreConnection;
import com.om.mxs.client.japi.MxsObject;
import com.om.mxs.client.japi.Vault;
import com.om.mxs.client.japi.cred.Credentials;

/**
 * Example presenting creation of new connection to MatrixStore cluster and authentication step.
 */
public class AuthenticationSample {

    private static final String[] hosts = new String[] { "node153", "node154" };
    private static final String vaultId = "c85ccb4b-b5b6-11e8-b963-ef69c21c706d";

    public static void main(String[] args) throws IOException {

        // prepare credentials used to authenticate user
        String username = "apitest";
        char[] password = "password".toCharArray();
        Credentials loginCred = Credentials.newUsernamePasswordCredentials(username, password);

        executeExample(loginCred);

        // prepare access key credentials
        String accessKeyId = "2f1eb24c-d349-4736-bde9-a38756a63e03";
        String accessKeySecret = "rPZ90vVwFz178guRqbuWlkNI9Jjkqftiq0XaHAiR0et0ssMJ";
        Credentials accesskeyCred = Credentials.newAccessKeyCredentials(accessKeyId, accessKeySecret);

        executeExample(accesskeyCred);
    }

    private static void executeExample(Credentials cred) throws IOException {
        // create connection to MatrixStore
        // It allows to specify clusterID and protocol name
        // clusterID is required only for secure protocols: srpc and asrpc
        // Created connection can be shared, but once closed it will affect all MatrixStore instances sharing it
        MatrixStoreConnection conn = MatrixStoreConnection.builder().withHosts(hosts).build();

        MatrixStore mxs = MatrixStore.builder().withConnection(conn).withCredentials(cred).build();

        Vault vault = mxs.openVault(vaultId);

        MxsObject object = vault.createObject();
        System.err.println("Created: " + object.getId());

        // disposing a vault invalidates the instance but it does not close MatrixStoreConnection
        vault.dispose();

        // disposing MatrixStore ends user's session but it does not close MatrixStoreConnection
        mxs.dispose();

        // connection can be closed explicitly on the MatrixStoreConnection instance or by calling closeConnection() method
        conn.close();
        // or close on MatrixStore instance
        // this automatically disposed MatrixStore instance (ends user's session) 
        mxs.closeConnection();
    }

}
