package com.om.mxs.client.japi.samples;

import java.io.IOException;

import com.om.mxs.client.japi.MatrixStore;
import com.om.mxs.client.japi.MatrixStoreConnection;
import com.om.mxs.client.japi.cred.Credentials;
import com.om.mxs.client.japi.metadata.ClusterAttributesView;

/**
 * Example showing you have to get cluster id and name.
 * 
 * Expected output similar to:
 * Id of the cluster is: 65ac8b3a-a73e-f23b-77f1-17ca016090c1
 * Name of the cluster is: VM Cluster
 * 
 * @author David
 *
 */
public class ClusterAttributeViewSample {

	private static final String[] clusterHosts = new String[]{"nodevm"};
	
	public static void main(String[] vargs) throws IOException{
		// prepare credentials used to authenticate user
        String username = "test-user";
        char[] password = "pass0".toCharArray();
        Credentials cred = Credentials.newUsernamePasswordCredentials(username, password);
        
        MatrixStoreConnection conn = MatrixStoreConnection.builder().withHosts(clusterHosts).build();
        MatrixStore mxs = null;
        try{
        	mxs = MatrixStore.builder().withConnection(conn).withCredentials(cred).build();
        	
        	//Get the attributes object.
        	ClusterAttributesView clusterAtts = mxs.getClusterAttributesView();
        	System.out.println("Id of the cluster is: " + clusterAtts.clusterId());
        	System.out.println("Name of the cluster is: " + clusterAtts.clusterName());
        	
        	//Dispose of the MatrixStore instance after you're done with it.
        	mxs.dispose();
        }finally{
        	//Close the MatrixStoreConnection one all resources that use it are disposed.
        	conn.close();
        }
	}
	
}
